@@ -11,6 +11,66 @@
  */
 
 
+
+function cal_admin_block_do()
+{
+
+    global $username;
+    if (isset($_SESSION['username'])) 
+        $username = $_SESSION['username'];
+
+    $approved = approve_cal_admin($username);
+    if (!($approved == 'SUPERUSER' || $approved == 'LIMITED'))
+        return;
+
+    global $optpage_blocks;
+    $optpage_blocks[] = array(
+        'name' => _("Shared Calendar Administration"),
+        'url'  => '../plugins/calendar/admin_options.php',
+        'desc' => _("Create and maintain shared calendars. Assign access by user or create publicly available calendars"),
+        'js'   => false
+        );
+
+}
+
+
+// returns "SUPERUSER" if the user in question has 
+// permission to edit any and all calendars, or 
+// "LIMITED" if the user only can edit their own
+// calendar(s), or "NONE" if the user has no administrative
+// permissions
+//
+function approve_cal_admin($user) {
+
+    $debug = 0;
+
+    global $admins;
+
+    include_once(SM_PATH . 'plugins/calendar/data/config.php');
+
+    foreach ($admins as $admin => $perms) 
+    {
+
+        if ($debug) echo "username=$user admin=$admin<br>admin == username ?? --> ". (strtolower($user)==strtolower($admin))."<br>";
+
+
+        if (preg_match('/^' . str_replace(array('?', '*'), array('\w{1}', '.*?'),
+                       strtoupper($admin)) . '$/', strtoupper($user)))
+        {
+            $perms = trim($perms);
+            if (strtolower($perms) == 'yes')
+                return 'SUPERUSER';
+            else
+                return 'LIMITED';
+        }
+
+    }
+
+    return 'NONE';
+
+}
+
+
 function calendar_header() {
     //Add Second layer ofCalendar links to upper menu
     global $color,$year,$day,$month,$cal;
@@ -28,6 +88,8 @@ function calendar_header() {
     print "<tr><td><center><h3>$print_cal Calendar</h3></center></td></tr>";
 
 
+    displayInternalLink("plugins/calendar/year.php?year=$year&month=$month&day=$theDay&cal=".urlencode($cal),_("Year View"),"right");
+    echo "&nbsp;&nbsp\n";
     displayInternalLink("plugins/calendar/calendar.php?year=$year&month=$month&cal=".urlencode($cal),_("Month View"),"right");
     echo "&nbsp;&nbsp\n";
     displayInternalLink("plugins/calendar/day.php?year=$year&month=$month&day=$theDay&cal=".urlencode($cal),_("Day View"),"right");
