@@ -194,7 +194,7 @@ function save_calendar_list($data_dir, $update_list, $save_type) {
             $line = '';
             $line .= 'P';
             $length = strlen($public_list[$x]);
-            $line .= "{".$length."}{OWNER=".$calendar_owners[$public_list[$x]]."} ".$public_list[$x];
+            $line .= "{".$length."}{OWNER=".$calendar_owners[$public_list[$x]]." ".$public_list[$x];
             fwrite($fp, $line."\n", 1024);
         }
         fclose($fp);
